==> haskell-language-javascript-0.7.1.0-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-javascript
version:              0.7.1.0
visibility:           public
id:                   language-javascript-0.7.1.0-8HUGfiMgGZ85z0q3mTKzOI
key:                  language-javascript-0.7.1.0-8HUGfiMgGZ85z0q3mTKzOI
license:              BSD-3-Clause
copyright:
    (c) 2010-2015 Alan Zimmerman
    (c) 2015-2019 Erik de Castro Lopo
    (c) 2018      Daniel Gasienica

maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman
homepage:             https://github.com/erikd/language-javascript
synopsis:             Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.

    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.

category:             Language
abi:                  05b2ad18ffbab24bd7b319ab0004e97b
exposed:              True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar7
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify

hidden-modules:
    Language.JavaScript.Parser.LexerUtils
    Language.JavaScript.Parser.ParseError
    Language.JavaScript.Parser.ParserMonad
    Language.JavaScript.Parser.Token

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-javascript
hs-libraries:         HSlanguage-javascript-0.7.1.0-8HUGfiMgGZ85z0q3mTKzOI
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.4.1-1jE2jTKoqGH3aj9MBDpFLw bytestring-0.11.5.3
    containers-0.6.7 mtl-2.2.2 text-2.0.2
    utf8-string-1.0.2-JqS4SAQdze6LQzXf6ug2xB

haddock-interfaces:
    /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock

haddock-html:         /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-javascript-0.7.1.0-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 language-javascript
version:              0.7.1.0
visibility:           public
id:                   language-javascript-0.7.1.0-HA4aXaf4DziJ7QTnYVBUev
key:                  language-javascript-0.7.1.0-HA4aXaf4DziJ7QTnYVBUev
license:              BSD-3-Clause
copyright:
    (c) 2010-2015 Alan Zimmerman
    (c) 2015-2019 Erik de Castro Lopo
    (c) 2018      Daniel Gasienica

maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman
homepage:             https://github.com/erikd/language-javascript
synopsis:             Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.

    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.

category:             Language
abi:                  7a5dcedbffd7ed40f5758d42be93cd63
exposed:              True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar7
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify

hidden-modules:
    Language.JavaScript.Parser.LexerUtils
    Language.JavaScript.Parser.ParseError
    Language.JavaScript.Parser.ParserMonad
    Language.JavaScript.Parser.Token

import-dirs:          /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/language-javascript-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-javascript
hs-libraries:         HSlanguage-javascript-0.7.1.0-HA4aXaf4DziJ7QTnYVBUev
depends:
    array-0.5.4.0 base-4.17.2.1
    blaze-builder-0.4.4.1-CRExiPUdjbG8JKbY7llSvY bytestring-0.11.5.3
    containers-0.6.7 mtl-2.2.2 text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock

haddock-html:         /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
